UploadProgress class

Annotations

Constructors

UploadProgress({required int bytesTransferred, required int? totalBytes, required UploadStatus status, Object? error})
const

Properties

bytesTransferred int
final
error Object?
final
fraction double?
0.0 .. 1.0, or null when totalBytes is unknown.
no setter
hashCode int
The hash code for this object.
no setterinherited
isTerminal bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status UploadStatus
final
totalBytes int?
null if total size is unknown (e.g. streaming source).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited